Accelerated Computing · Est. 1993 · Santa Clara
THE ENGINE ROOM OF INTELLIGENCE.
One architecture. From a single die of silicon to planet-scale AI factories — this is a descent through the machine that thinks.
Data centers · Blackwell · NVLink
AI FACTORIES
The data center is no longer a warehouse for files. It is a machine with one job: manufacturing intelligence. Raw power in, tokens out — measured not in megabytes, but in reasoning per watt.
- GB300 NVL72
- DGX SuperPOD
- Spectrum-X
- Quantum-X Photonics
- Rubin · 2026
Gaming · RTX · Neural rendering
GEFORCE RTX.
Ray tracing was the beginning. Now the frame itself is imagined — neural shaders, DLSS 4 multi-frame generation, and paths of light simulated before your eyes knew to ask.
COMPUTE IS THE NEW GRAVITY.
Everything built this century bends around it.
Simulation · OpenUSD · Digital twins
OMNI VERSE
Before a factory is built, it is simulated. Before a robot walks, it walks a million times in a world made of light and physics. Omniverse is where the physical world rehearses.
Factories, warehouses and cities mirrored atom-for-atom in OpenUSD, streamed at planetary scale.
BMW · Siemens · FoxconnPhotoreal worlds that generate the edge cases reality is too stingy to provide — on demand, labeled, infinite.
Omniverse ReplicatorWorld foundation models that understand physics — predicting the next frame of reality itself.
NVIDIA CosmosJetson · DRIVE · Isaac · GR00T
MACHINES THAT MOVE
Intelligence is leaving the screen. Jetson thinks at the edge, DRIVE reads the road, Isaac teaches robots to grasp — and GR00T gives humanoids a mind that generalizes.
CUDA · CUDA-X · Developer universe
THE CUDA UNIVERSE
Beneath everything above — every factory, every frame, every twin — sits a kernel. Millions of threads launched like a choir, each one singing exactly one note, perfectly on time.
__global__ void saxpy(int n, float a,
const float *x, float *y) {
int i = blockIdx.x * blockDim.x + threadIdx.x;
if (i < n) y[i] = a * x[i] + y[i];
}
// one line. four million threads.
saxpy<<<(n + 255) / 256, 256>>>(n, 2.0f, x, y);
cudaDeviceSynchronize();